==> react-redux-grid-1.7.0.tgz: package/src/components/core/draganddrop/DragAndDropManager.js <==
import { CLASS_NAMES } from '../../../constants/GridConstants';
import { prefix } from '../../../util/prefix';

export default class DragAndDropManager {
    initDragable(initialProps) {

        const defaults = {
            onDragStart: this.handleDragStart,
            onDrag: this.handleDrag,
            onDragOver: this.handleDragOver,
            onDragLeave: this.handleDragLeave,
            onDragEnd: this.handleDragEnd,
            onDrop: this.handleDrop,
            draggable: true,
            className: prefix(CLASS_NAMES.DRAG_HANDLE)
        };

        const props = initialProps
            ? Object.assign(defaults, initialProps) : defaults;

        return props;
    }

    handleDragStart(reactEvent) {
        reactEvent.dataTransfer.setData('Text',
            JSON.stringify({ preventBubble: true, validDrag: true })
        );
        /**
        * hiding the chrome default drag image -- go upvote this
        * http://stackoverflow.com/questions/7680285/how-do-you-turn-off-setdragimage
        **/

        const dragIcon = document.createElement('img');
        dragIcon.src = 'data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==';

        if (reactEvent.dataTransfer.setDragImage) {
            reactEvent.dataTransfer.setDragImage(dragIcon, -10, -10);
        }
    }

    handleDrag() {}

    handleDragOver(reactEvent) {

    }

    handleDragLeave(reactEvent) {
        reactEvent.preventDefault();
    }

    handleDragEnd(reactEvent) {
        reactEvent.preventDefault();
    }

    handleDrop(reactEvent) {
        reactEvent.preventDefault();

        const eventType = JSON.parse(reactEvent.dataTransfer.getData('Text'));

        if (eventType && eventType.preventBubble) {
            reactEvent.stopPropagation();
        }
    }
}

==> react-redux-grid-1.9.3.tgz: package/src/components/core/draganddrop/DragAndDropManager.js <==
import { CLASS_NAMES } from '../../../constants/GridConstants';
import { prefix } from '../../../util/prefix';

export default class DragAndDropManager {
    initDragable(initialProps = {}) {

        const defaults = {
            onDragStart: this.handleDragStart,
            onDrag: this.handleDrag,
            onDragOver: this.handleDragOver,
            onDragLeave: this.handleDragLeave,
            onDragEnd: this.handleDragEnd,
            onDrop: this.handleDrop,
            draggable: true,
            className: prefix(CLASS_NAMES.DRAG_HANDLE)
        };

        const props = initialProps
            ? Object.assign({}, defaults, initialProps) : defaults;

        return props;
    }

    handleDragStart(reactEvent) {
        reactEvent.dataTransfer.setData('Text',
            JSON.stringify({ preventBubble: true, validDrag: true })
        );
        /**
        * hiding the chrome default drag image -- go upvote this
        * 7680285/how-do-you-turn-off-setdragimage
        **/

        const dragIcon = document.createElement('img');
        dragIcon.src = 'data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw=='; // eslint-disable-line max-len

        if (reactEvent.dataTransfer.setDragImage) {
            reactEvent.dataTransfer.setDragImage(dragIcon, -10, -10);
        }
    }

    handleDrag() {}

    handleDragOver(reactEvent) {

    }

    handleDragLeave(reactEvent) {
        reactEvent.preventDefault();
    }

    handleDragEnd(reactEvent) {
        reactEvent.preventDefault();
    }

    handleDrop(reactEvent) {
        reactEvent.preventDefault();

        const eventType = JSON.parse(reactEvent.dataTransfer.getData('Text'));

        if (eventType && eventType.preventBubble) {
            reactEvent.stopPropagation();
        }
    }
}
